@@ -1,4 +1,4 @@
-context("chunk")
+context("cross_join")
 
 test_that("cross_join", {
   tab = cross_join(list(a = 1:3, b = 1:2))
